%% Solution to Statistics Tutorial
% Author: Mara Vaihinger, System and Control Theory, University of Freiburg
clear; close all; clc;

%% Contiuous Random Variables
% Load data
load('position.mat')

% Plot the data
figure(1);
plot(position(:,1), position(:,2), '+b');
title('Position data of the GPS device');
legend('measurements');
axis equal;
hold on;

%% Task 1: Expectation Value
N = size(position,1);
positionEV = 1/N .* sum(position);
%positionEV = mean(position);
plot(positionEV(1), positionEV(2), '+r');

%% Task 2: Variance
varX = var(position(:,1));
varY = var(position(:,2));
sprintf('The variances of the measurement data are \n varX = %d [m^2]\n varY = %d [m^2].', varX,varY)
stdX = std(position(:,1));
stdY = std(position(:,2));
sprintf('The standard deviations of the measurement data are \n stdX = %d [m]\n stdY = %d [m].', stdX,stdY)

%% Task 3: Covariance & Correlation
covMat = cov(position(:,1),position(:,2))
correlationXY = corr(position)
sprintf('Is the noise correlated? \n - No, the correlation between the noise in x- and y-direction is close to zero.')

%% Task 4: Confidence Ellipsoid
% Step 1: Compute Eigenvalues and Eigenvectors of Covariance Matrix
[V, D] = eig(covMat);

% Step 2: Creat 50 points of a unit circle
xy=[cos(linspace(0,2*pi,50)); sin(linspace(0,2*pi,50))];

% Step 3: Deform unit circle using eigenvalues and eigenvectors
confEllipse = [positionEV(1); positionEV(2)]*ones(1,50) + V*sqrt(D)*xy;

% Step 4: Plot ellipsoid
plot(confEllipse(1,:), confEllipse(2,:), 'k', 'LineWidth', 2);

%% Additional Tasks
students = [24 33 29 10 2 0 0 1]; % amount of students having 0,1,2,3,4,5,6,more than 7 siblings
siblings = [0 1 2 3 4 5 6 7]; % RV

% Task a) Plot discrete PDF
figure(2)
bar(siblings, students/sum(students));
xlabel('x = Amount of Siblings');
ylabel('PDF of x: P(X = x)');
title('PDF of the random variable describing the amount of siblings in a class');
hold on;

% Task b) Mean
meanSiblings = 1/sum(students) * siblings * students.'  % mean = (24 * 0 + ... + 1*7)/99
line([meanSiblings, meanSiblings], [0,0.5], 'Color', 'r');
legend('PDF', 'Mean');

% Task c)
varSiblings = 1/sum(students) * (siblings - meanSiblings).^2 * students.'
